tonalitytools.QualityIndicator
==============================

.. inheritance-diagram:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator
   :private-bases:

.. autoclass:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.is_uppercase

.. autoattribute:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.quality_string

.. autoattribute:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__eq__

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__ne__

.. automethod:: abjad.tools.tonalitytools.QualityIndicator.QualityIndicator.QualityIndicator.__repr__
